package net.binggl.lib.ajax.datatables;

import java.util.HashMap;

import javax.servlet.http.HttpServletRequest;

/**
 * small helper to parse the supplied datatable parameters found:
 * http://www.lunatech
 * -research.fr/archives/2011/02/07/ajax-datatables-playframework
 * 
 * @author henrik
 * 
 */
public class DataTableParameters {

	public int echo;
	public Integer offset;
	public int page;
	public Integer pageSize;
	public String search;
	public Integer orderByColumnIndex;
	public String order;
	public HashMap<String, String> columnSearch = new HashMap<String, String>();

	/**
	 * default
	 * 
	 * @param request
	 */
	public DataTableParameters(final HttpServletRequest request) {

		this.echo = this.parseParam(request, "sEcho");

		// Paging
		this.offset = this.parseParam(request, "iDisplayStart");
		this.pageSize = this.parseParam(request, "iDisplayLength");
		this.page = this.offset == null ? 1 : (this.offset / this.pageSize) + 1;

		// Sorting (first sort column only).
		final Integer sortingColumns = this.parseParam(request, "iSortingCols");
		if (sortingColumns != null) {
			this.orderByColumnIndex = this.parseParam(request, "iSortCol_0");
			final String sortDirection = request.getParameter("sSortDir_0");

			this.order = sortDirection == null ? null : sortDirection.toUpperCase();
		}

		// Search: the overall full-text search
		this.search = request.getParameter("sSearch");

		// also possible, that index-based search parameters are supplied
		int iColumns = this.parseParam(request, "iColumns");
		String indexSearchValue = "";
		String indexSearchColumName = "";
		for (int i = 0; i < iColumns; ++i) {
			indexSearchValue = request.getParameter("sSearch_" + Integer.toString(i));
			// lookup the name of the colum
			indexSearchColumName = request.getParameter("mDataProp_" + Integer.toString(i));
			if(indexSearchValue != null && !"".equals(indexSearchValue)) {
				if(indexSearchColumName != null && !"".equals(indexSearchColumName))
					this.columnSearch.put(indexSearchColumName, indexSearchValue);
			}
		}
	}

	/**
	 * helpers
	 */

	/***
	 * parse the supplied param
	 * 
	 * @param request
	 * @param param
	 * @return
	 */
	private int parseParam(HttpServletRequest request, String param) {
		int intValue = 0;
		String paramValue = request.getParameter(param);
		if (paramValue != null && !"".equals(paramValue)) {
			intValue = Integer.parseInt(paramValue);
		}
		return intValue;
	}

}
